# Study Manager Scripts
> Collection of scripts I used for managing my studies

## main.py
Contains core functionality of the Study Manager. Namely it can:
- Create symlink of the current relevant course (CC) to a easily reachable destination like `~/CurrentCourse/`
- List relevant resources for the CC like links, username, passwords, etc.

### Usage
- `main.py -c` to select CC
- `main.py -l` to list resources
- `main.py -t` to create entries for all lecture in your calendar using khal

### Configuration
- Create config file at `~/.config/StudyManager/config` containing **all** the following options. See [./config](config) for an example
    - `CURRENT_COURSE_LINK_DST`: Path to folder containing all relevant courses
    - `COURSES_ROOT_DIR`: Path to symlink for the CC
    - `INFO_FILE`: Name of infofile contained in CC
    - `TIMETABLE_FILE`: Name of timetable file contained in CC
    - `CALENDAR`: Name of Khal calendar to use
    - `SEMESTER`: Unique identifier for current semester
    - `SEMESTER_START`: Date of first day in semester 
    - `SEMESTER_END`: Date of last day in semester
- Create folders for each course in `COURSES_ROOT_DIR`
- Create `INFO_FILE` inside each course containing information about the course. See [./info.yaml](info.yml) for an example
    - `title`: Name of lecture (required)
    - `short`: Shortform of lecture title (required)
    - Arbitrarily other key/value pairs like `web`, `username`, etc. (optional)
- Create `TIMETABLE_FILE` inside each course containing the timetable of that course. The structure for one event is as follows. See [./info.yaml](info.yml) for an example
    - `ArbitraryName`:
      - `day`: Day of the event. One of: `Mon`, `Tue`, `Wed`, `Tue`, `Fri`, `Sat`, `Sun`
      - `start`: Startime of event
      - `end`: Endtime of event
      - `location`: Location of event
      - `type`: Short identifier of type of event. Like e.g. `L` for lecture, `E` for exercise, etc.

### Requirements
- [Python3](https://www.python.org/)
- [Rofi](https://github.com/davatorium/rofi)
- [python-rofi](https://pypi.org/project/python-rofi/)
- [Khal](https://github.com/pimutils/khal) (optional)

## theAltEvent.py
> Create calendar entries for courses of [theAlternative](https://thealternative.ch/)

### Usage
- Clone [theAlternative Website](https://gitlab.ethz.ch/thealternative/website)
- Run `./theAltEvent.py` and pass as arguments all `.yml` files of the events located in `events` that you want to create an empty for. E.g. `theAltEvent.py ./events/*.yml`

### Requirements
- [Python3](https://www.python.org/)
- [Khal](https://github.com/pimutils/khal) (optional)
